"""Base module for the Python Durable functions."""
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)  # type: ignore
